# Premier League API

[![Python Checking](https://github.com/Cyb3r-Jak3/preimer_league_api/actions/workflows/lint.yml/badge.svg)](https://github.com/Cyb3r-Jak3/preimer_league_api/actions/workflows/lint.yml) [![Documentation Status](https://readthedocs.org/projects/preimer-league-api/badge/?version=latest)](https://premier-league.docs.jwhite.network/en/latest/?badge=latest)

An **unofficial** api client for pulling player and fixture data from the [Premier League](https://www.premierleague.com/)

It would seem that the API backend is suited to support more leagues as well as manager so there could be future work to expand there.

There are a ton of stats that you can get for players. Read the [documentation](https://premier-league.docs.jwhite.network/en/latest/) to get started


### Goals

* Other leagues
* Use as a library rather than client
* Manager stats
